summaryrefslogtreecommitdiffstats
path: root/bin/d-i_build.sh
diff options
context:
space:
mode:
Diffstat (limited to 'bin/d-i_build.sh')
-rwxr-xr-xbin/d-i_build.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/bin/d-i_build.sh b/bin/d-i_build.sh
index 73e39b27..4f786df1 100755
--- a/bin/d-i_build.sh
+++ b/bin/d-i_build.sh
@@ -20,9 +20,10 @@ init_workspace() {
rm -fv *.deb *.udeb *.dsc *_*.build *_*.changes *_*.tar.gz
#
# svn checkout and update is done by jenkins job
#
- svn status
+ git config -l
+ git status
}
pdebuild_package() {
@@ -20,9 +20,10 @@ init_workspace() {
rm -fv *.deb *.udeb *.dsc *_*.build *_*.changes *_*.tar.gz
#
- # svn checkout and update is done by jenkins job
+ # git clone and pull is done by jenkins job
#